    containers:

    	open container from an image archive:
    		[xonsh] docker container list
    		[xonsh] docker import EC_Book_2.tar
    		[xonsh] docker

    	save container as image archive:
    		[xonsh] docker export --output="EC_Book_2.tar" a25061773ac1

    	save changes to a container:
    		[xonsh]

    	delete:
    		[xonsh] docker container rm {CONTAINER ID}

    	delete every non-running container:
    		[xonsh] docker container prune -f

    	list every:
    		[xonsh] docker container list --all

    	list:
    		[xonsh] docker container list